aboutsummaryrefslogtreecommitdiffstats
path: root/scripts/qdoc2tasks.pl
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/qdoc2tasks.pl')
-rwxr-xr-xscripts/qdoc2tasks.pl5
1 files changed, 3 insertions, 2 deletions
diff --git a/scripts/qdoc2tasks.pl b/scripts/qdoc2tasks.pl
index 066a857c27..244a0a13a4 100755
--- a/scripts/qdoc2tasks.pl
+++ b/scripts/qdoc2tasks.pl
@@ -41,8 +41,9 @@ use warnings;
while (my $line = <STDIN>) {
chomp($line);
# --- extract file name based matching:
- # D:/.../qaxbase.cpp:3231: warning: Cannot tie this documentation to anything
- if ($line =~ /^(..[^:]*):(\d+): warning: (.*)$/) {
+ # Qt 5.10: D:/.../qaxbase.cpp:3231: warning: Cannot tie this documentation to anything
+ # Qt 5.11: D:/.../qaxbase.cpp:3231: (qdoc) warning: Cannot tie this documentation to anything
+ if ($line =~ /^(..[^:]*):(\d+): (?:\(qdoc\) )?warning: (.*)$/) {
my $fileName = $1;
my $lineNumber = $2;
my $text = $3;